
	use "$output/enrol_pooled.dta", clear											// Use child-level data: note this is a more primitive file than used by clogit

		gen 	agecat = 1 if age>=6 	& age<=13
		replace agecat = 2 if age>=14 	& age<=19

		generat ner_pri_g = publicP*100 if agecat==1 								// NER simply uses a dummy for enrolment for kids in the right age category
		generat ger_pri_g = 100 if publicP==1										// GER uses all children enrolled in the numerator....
		replace ger_pri_g = 0   if publicP==0 & agecat==1 							// But only lets the denominator take a value of 0 if the child is 

		generat ner_sec_g = publicS*100 if agecat==2 
		generat ger_sec_g = 100 if publicS==1
		replace ger_sec_g = 0   if publicS==0 & agecat==2 

		generat ner_pri_p = privateP*100 if agecat==1 
		generat ger_pri_p = 100 if privateP==1
		replace ger_pri_p = 0   if privateP==0 & agecat==1 

		generat ner_sec_p = privateS*100 if agecat==2 
		generat ger_sec_p = 100 if privateS==1
		replace ger_sec_p = 0   if privateS==0 & agecat==2 

***************************
*** For sum stats table ***
***************************

		gen primage = agecat==1
		svyset [pw=weight_hh]
		svy: ratio publicP primage 	if year==0
		svy: ratio publicP primage 	if year==1
		svy: ratio privateP primage if year==0
		svy: ratio privateP primage if year==1
			
		mean ner_pri_g [pw=weight_hh] if year==0
		mean ner_pri_g [pw=weight_hh] if year==1
		mean ner_pri_p [pw=weight_hh] if year==0
		mean ner_pri_p [pw=weight_hh] if year==1
		
		mean hhh_educ [pw=weight_hh] if publicP==1 & year==0
		mean hhh_educ [pw=weight_hh] if publicP==1 & year==1
		mean hhh_educ [pw=weight_hh] if privateP==1 & year==0
		mean hhh_educ [pw=weight_hh] if privateP==1 & year==1
	
		mean exp_feesP97 [pw=weight_hh] if publicP==1 & year==0
		mean exp_feesP97 [pw=weight_hh] if publicP==1 & year==1
		mean exp_feesP97 [pw=weight_hh] if privateP==1 & year==0
		mean exp_feesP97 [pw=weight_hh] if privateP==1 & year==1


*****************************************
*** Re-create the lost NER pie chart! ***
*****************************************

	preserve
		collapse (mean) ner_pri_g ner_pri_p [pw=weight_hh], by(year)
		replace year = 1997 if year==0
		replace year = 2006 if year==1
		gen ner_pri_n = 100 - ner_pri_g - ner_pri_p
		#delimit ;
		graph pie ner_pri_n ner_pri_g ner_pri_p, 
			by(year, title(Net Enrolment Rates by School Type) note("")) 
			plabel(_all percent, format(%2.1f) size(vlarge) color(white)) /*plabel(_all name)*/ 
			scheme(s2color) noclockwise 
			legend(order(1 "Not enrolled" 2 "Government Primary" 3 "Private Primary"))
			pie(3, explode);
		#delimit cr
	restore

	*** replace expenditure quintiles (old draft) with education variable based on referees' comments
	forval k=1/5 { 
		gen q`k'=0 if hhh_educ~=. 
	}
	replace q1=1 if hhh_educ==0
	replace q2=1 if hhh_educ>=1 & hhh_educ<=7
	replace q3=1 if hhh_educ==8 
	replace q4=1 if hhh_educ>=9 & hhh_educ<=12
	replace q5=1 if hhh_educ>=13 & hhh_educ<=15


*********************************************************
*** Average Attendance Rates by Exp. Quintile and Sex ***
*********************************************************

	*** Small program to overwrite regression coefficients in latex with the GER 
	capture program drop createger
	program define createger
		args stub depvar age
		global sstub  = "$s" + "`stub'"
		global mat = "sum_" + "$sq" +  "_b"
		count if e(sample) & `depvar'==100											// Count the number of children enrolled, all ages
		local num = r(N)												
		count if e(sample) & agecat==`age'											// Count the number of children in age category
		local den = r(N)
		mat $mat[1,colnumb($mat,"$sstub")] = 100*`num'/`den'						// Replace coefficient with total enrolment / age-group population
	end

	gen q0=1 if hhh_educ~=.
	foreach s in g p{
		forval q = 0/5{

			global s  = "`s'"
			global sq = "`s'" + "`q'"

			*** Primary
			reg ner_pri_`s' if q`q'==1 & year==0 [pw=weight_hh]
													est2vec sum_`s'`q', replace vars(_cons) name(`s'p97n)
			reg ner_pri_`s' if q`q'==1 & year==1 [pw=weight_hh]
													est2vec sum_`s'`q', addto(sum_`s'`q') name(`s'p06n)
			reg ger_pri_`s' if q`q'==1 & year==0 [pw=weight_hh]
													est2vec sum_`s'`q', addto(sum_`s'`q') name(`s'p97g)
													createger p97g ger_pri_`s' 1
			reg ger_pri_`s' if q`q'==1 & year==1 [pw=weight_hh]
													est2vec sum_`s'`q', addto(sum_`s'`q') name(`s'p06g)
													createger p06g ger_pri_`s' 1
		
			***Secondary 
			reg ner_sec_`s' if q`q'==1 & year==0 [pw=weight_hh]
													est2vec sum_`s'`q', addto(sum_`s'`q') name(`s's97n)
			reg ner_sec_`s' if q`q'==1 & year==1 [pw=weight_hh]
													est2vec sum_`s'`q', addto(sum_`s'`q') name(`s's06n)
			reg ger_sec_`s' if q`q'==1 & year==0 [pw=weight_hh]
													est2vec sum_`s'`q', addto(sum_`s'`q') name(`s's97g)
													createger s97g ger_sec_`s' 2
			reg ger_sec_`s' if q`q'==1 & year==1 [pw=weight_hh]
													est2vec sum_`s'`q', addto(sum_`s'`q') name(`s's06g)
													createger s06g ger_sec_`s' 2

			matrix rowname sum_`s'`q'_b = "`q'"
		}
	}

	#delimit ;
	foreach v in b se{;
		mat sum_`v' = 	( 	sum_g0_`v' \ sum_g1_`v' \ sum_g2_`v' \ sum_g3_`v' \ sum_g4_`v' \ sum_g5_`v' \ 
							sum_p0_`v' \ sum_p1_`v' \ sum_p2_`v' \ sum_p3_`v' \ sum_p4_`v' \ sum_p5_`v' );
	};
	#delimit cr

	est2tex sum, preserve path("$output") levels (90 95 99) fancy nolabel replace digits(1) suppress extracol(2 4 6)

exit
