
use "$output/enrol_pooled_hh.dta", clear

	gen FPE = year==1
	tab prov, g(provdum)
	foreach var in enrolP publicP privateP publicS privateS{
	gen `var'FPE = `var'*FPE
	}

	label variable publicP 		"Children in public primary"
	label variable privateP 	"Children in private primary"
	label variable publicS 		"Children in public secondary"
	label variable privateS 	"Children in private secondary"
	label variable publicPFPE 	"FPE $ \times $ Children in public primary"
	label variable privatePFPE 	"FPE $ \times $ Children in private primary"
	label variable publicSFPE 	"FPE $ \times $ Children in public secondary"
	label variable privateSFPE 	"FPE $ \times $ Children in private secondary"
	label variable enrolP 		"No. of kids in prim."
	label variable enrolPFPE 	"FPE $ \times $ No. of kids in prim."

	replace exp_edtotalP97 = 0 if enrolP==0
	replace exp_edtotalS97 = 0 if enrolS==0

	gen feegovP 	= exp_feesP97 / publicP
	gen feepriP 	= exp_feesP97 / privateP
	gen feegovP97 	= feegovP if year==0
	gen feegovP06 	= feegovP if year==1
	gen feepriP97 	= feepriP if year==0
	gen feepriP06 	= feepriP if year==1


*****************************
*** Expenditure Equations ***
*****************************

	reg exp_edtotalP97 publicP privateP publicPFPE privatePFPE, nocons robust
		est2vec expenditure, replace vars(publicP privateP publicPFPE privatePFPE publicS privateS publicSFPE privateSFPE) name(totP)
	reg exp_feesP97 publicP privateP publicPFPE privatePFPE, nocons robust
		est2vec expenditure, addto(expenditure) name(feeP)
	reg exp_edtotalS97 publicS privateS publicSFPE privateSFPE, nocons robust
		est2vec expenditure, addto(expenditure) name(totS)
	reg exp_feesS97 publicS privateS publicSFPE privateSFPE, nocons robust
		est2vec expenditure, addto(expenditure) name(feeS)
		est2tex expenditure, preserve path("$output") levels (90 95 99) extracol(2) mark(stars) fancy label replace digits(2)

*****************
*** Make CDFs ***
*****************

	drop if publicP!=0 & privateP!=0						// For disagg data, drop hhs with kids in both public and private: don't know how to apportion their expenditure.  Only 400 out of 17,000 hhs.

	*** All in USD
		foreach var in govP97 govP06 priP97 priP06{
			replace fee`var' = fee`var'*.01835
		}
		
	***	Individual level
		gen feegovP06cap = feegovP06 + (344*.01835) if feegovP06!=.
		foreach var in govP97 govP06 priP97 priP06 govP06cap{
			replace fee`var' = 1 if fee`var'==0
			replace fee`var' = ln(fee`var')
		}

		cumul feegovP97 	[aw=weight_hh], g(cumgovP97)
		cumul feegovP06cap 	[aw=weight_hh], g(cumgovP06)

	*** Strange bug here in my method: for repeated values of 1st var below, cumul creates a range of values for 2nd var, but sort fails to put them in the right order, creating spurious non-monotonicities in the CDF
		foreach var in govP97 govP06 {
			duplicates tag fee`var', g(dup)
			replace fee`var' = fee`var' + .02*cum`var' if dup>0	// this will ensure there are no more duplicates in the x var of graph
			drop dup
		}

	twoway 	(line cumgovP97 feegovP97 		if feegovP97>=1 & feegovP97<=6, sort lwidth(thick))									///
			(line cumgovP06 feegovP06cap 	if feegovP06cap>=1 & feegovP06cap<=6, sort lpattern(dash) lwidth(thick)),			///	
			ytitle("Cumulative Probability")																					///
			xtitle("Financial resources per child in KSh 1997")																	///
			xlabel(2.302 "10")																									///
			legend(order(1 "CDF 1997" 2 "CDF 2006"))																			///
			scheme(s1manual) ylabel(, axis(1) grid)

exit


