drop _all
clear
capture clear matrix
set mem 800m
set more off
version 10


*** The primary school program is relatively complex: It estimates a clogit as part of the full Bayer-Timmins model.
*** The secondary school program is relatively simple: It simply runs a clogit and calculates standard errors for the mfx of the interaction terms

use "$output/enrol_pooled_clogit_sec.dta", clear						 
	keep 	year wmsdistrict* j sigma* poor* rich* educ* noneduc* kcpe selected selected_s pid did eaid iid year prov dist ea hh i age* provdum* enrol_NPP_P enrol_NPP_S enrolP pubprivP pdummy* logfood logfoodFPE hhheduc hhheducFPE male maleFPE FPE weight_hh
	global 	Zi  = "logfood logfoodFPE hhheduc hhheducFPE" 				// Specify the RHS variables (Zi) you want to use
	global 	Xj  = "kcpe"
	global 	Xj0 = "djgovt djpriv"
	global 	level = 12													//	Clunky, but needed for the inputcoeffs.ado program: Primary=14, Secondary=12

****************************************************************
*** Create interaction terms with govt/priv dummies: Zi x Xj ***
****************************************************************

	gen 	djgovt 		= j==1
	gen 	djpriv 		= j==2
	gen 	djnone 		= j==0
	gen 	djgovtFPE	=djgovt*FPE
	gen 	djprivFPE	=djpriv*FPE

	global 	ZiXj = ""
	foreach xvar of varlist $Xj0{
		foreach zvar of varlist $Zi{
			gen 	`xvar'_`zvar' = `xvar'*`zvar'
			global 	ZiXj = "$ZiXj" + " " + "`xvar'_`zvar'" 
		}	
	}

***	and putting it in the first stage
	gen djgovtselected = djgovt*selected
	gen djprivselected = djpriv*selected
	gen djnoneselected = djnone*selected

	foreach var in djgovtselected djprivselected djnoneselected{
		bysort wmsdistrict: egen max`var' = max(`var')
		bysort wmsdistrict: egen min`var' = min(`var')
		keep if max`var'==1 & min`var'==0
	}

	foreach var in kcpe{
		bysort 	wmsdistrict FPE	: egen mean`var'_10 	= mean(`var') if j==1 & FPE==0
		bysort 	wmsdistrict FPE	: egen mean`var'_11 	= mean(`var') if j==1 & FPE==1
		bysort 	wmsdistrict FPE	: egen mean`var'_20 	= mean(`var') if j==2 & FPE==0
		bysort 	wmsdistrict FPE	: egen mean`var'_21 	= mean(`var') if j==2 & FPE==1
		bysort 	wmsdistrict		: egen mmean`var'_10 	= mean(mean`var'_10) 
		bysort 	wmsdistrict		: egen mmean`var'_20 	= mean(mean`var'_20) 
		bysort 	wmsdistrict		: egen mmean`var'_11 	= mean(mean`var'_11) 
		bysort 	wmsdistrict		: egen mmean`var'_21 	= mean(mean`var'_21) 
		keep 	if mmean`var'_10!=0 & mmean`var'_20!=0 & mmean`var'_11!=0 & mmean`var'_21!=0
		keep 	if mmean`var'_10!=. & mmean`var'_20!=. & mmean`var'_11!=. & mmean`var'_21!=.
	}
	

**************************************
*** Generate the dummies: delta_mj ***
**************************************

	levelsof wmsdistrict, local(levels)
	foreach l of local levels {
		forvalues k=0/2 {
		gen disdum`l'_`k'=(wmsdistrict==`l' & j==`k')

			forvalues r=0/1 {
			gen dum`l'_`k'_`r'=(j==`k' & wmsdistrict==`l' & FPE==`r')
			}
		}
	}

***	make sure this is always sorted in the same way when you use matrices, etc.
	drop dum*_0_*
	drop disdum*_0
	count
	sort wmsdistrict j FPE iid
	sort iid j

****************************************************
*** Step 1: run choice regression to generate b1 ***
****************************************************

	clogit selected $ZiXj dum*, group(iid) 
	mat bclogit = e(b)
	
********************************
*** Step 2: recover deltahat ***
********************************

	qui reg selected $ZiXj dum*, nocons
	scalar n=e(k)
	global k: word count $ZiXj 
	global k = $k + 1
	mat deltamat=bclogit[1,$k..n]'

*******************************************
*** Step 3: generate instrumented sigma ***
*******************************************
 
***	Only done for primary, not secondary sample		
			
*****************************************************
****Step 4: run choice specific FE regression********
*****************************************************

	sort wmsdistrict j FPE iid
	preserve
		collapse (mean) djgovt djpriv djgovtFPE djprivFPE, by(wmsdistrict j FPE)
		drop if j==0
		sort wmsdistrict j FPE
		svmat deltamat, names(delta)
		rename delta1 delta
		regress delta djgovt djpriv djgovtFPE djprivFPE, noconstant
		mat b=e(b)
		mat list b
		mat list e(V)
	restore
	
	***	4b: get new coefficient b0
		mat breg=e(b)
		clogit selected $ZiXj djgovt djpriv djgovtFPE djprivFPE, group(iid)
		inputcoeffs
		predict pinitial

****************************************************
*** Calculate average marginal effects CORRECTLY ***
****************************************************

	global IndRegPre  = "djgovt djpriv djgovt_logfood djgovt_hhheduc djpriv_hhheduc djpriv_logfood" 
	global Zi="logfood hhheduc"	

	***********
	*** FPE *** 
	***********

		gen keep_FPE=FPE
		foreach num of numlist 0/1 {
			replace FPE=`num'
			foreach var2 of varlist $IndRegPre {
					replace `var2'FPE=`var2'*FPE
			}
			predict p_`num'_FPE
		}
		gen 	dpdFPE=(p_1_FPE-p_0_FPE)
		replace FPE=keep_FPE
		foreach var2 of varlist $IndRegPre {
				replace `var2'FPE=`var2'*FPE
		}
		su 		dpdFPE if j==1
		su 		dpdFPE if j==2

	***********************************************
	*** continuous variable, evaluated at FPE=0 ***
	***********************************************
	
		global h=.001
		foreach var of varlist $Zi {
			replace `var'=`var'+$h
			replace FPE=0
			foreach vardum of varlist djgovt djpriv{
					replace `vardum'_`var'=`vardum'*`var'
			}
			foreach var2 of varlist $IndRegPre {
					replace `var2'FPE=`var2'*FPE
			}
			predict p_1_`var'_atFPE0 
			gen 	dpd`var'_atFPE0=(p_1_`var'_atFPE0-p_0_FPE)/$h
			replace `var'=`var'-$h
			replace FPE=keep_FPE
			foreach vardum of varlist djgovt djpriv{
					replace `vardum'_`var'=`vardum'*`var'
			}
			foreach var2 of varlist $IndRegPre {
					replace `var2'FPE=`var2'*FPE
			}
		}

	********************************
	*** difference in difference ***
	********************************

		foreach var of varlist $Zi {
			replace `var'=`var'+$h
			replace FPE=1
			foreach vardum of varlist djgovt djpriv{
					replace `vardum'_`var'=`vardum'*`var'
			}
			foreach var2 of varlist $IndRegPre {
					replace `var2'FPE=`var2'*FPE
			}
			predict p_11_`var'FPE 
			gen 	dpd`var'FPE=(p_11_`var'FPE-p_1_`var'_atFPE0)/$h- (p_1_FPE - p_0_FPE  )/$h
			replace `var'=`var'-$h
			replace FPE=keep_FPE
			foreach vardum of varlist djgovt djpriv{
					replace `vardum'_`var'=`vardum'*`var'
			}
			foreach var2 of varlist $IndRegPre {
					replace `var2'FPE=`var2'*FPE
			}
		}

		global IndRegMFX  = "dpdFPE dpdlogfood_atFPE0 dpdhhheduc_atFPE0 dpdlogfoodFPE dpdhhheducFPE"

		foreach num of numlist 1/2 {
			su 	$IndRegMFX if j==`num'
		}
		foreach num of numlist 1/2 {
			su 	dpdFPE if j==`num'
		}

*****************************************************  Stop here to see point estimates *************************************************

*************************************
*** CALCULATE THE STANDARD ERRORS ***
*************************************

	set more off
	capture gen keep_FPE=FPE
	global hh=0.0001
	mat g = I(`e(df_m)')*0

	foreach kk of numlist 0/`e(df_m)' {

		global r=`kk'
		di $r
		deltamethod

		***********
		*** FPE ***
		***********

			foreach num of numlist 0/1 {
					replace FPE=`num'
			foreach var2 of varlist $IndRegPre {
					replace `var2'FPE=`var2'*FPE
			}
			predict p_`num'_FPE_$r
			}
			gen 	dpdFPE_$r =(p_1_FPE_$r-p_0_FPE_$r)
			replace FPE=keep_FPE
			foreach var2 of varlist $IndRegPre {
					replace `var2'FPE=`var2'*FPE
			}

		***********************************************
		*** continuous variable, evaluated at FPE=0 ***
		***********************************************
		
			global h=.001
			foreach var of varlist $Zi {
				foreach num of numlist 0/1{
					di 		$h*`num'
					replace `var'=`var'+$h*`num'
					su 		`var'
					replace FPE=0
					foreach vardum of varlist djgovt djpriv{
							replace `vardum'_`var'=`vardum'*`var'
					}
					foreach var2 of varlist $IndRegPre {
							replace `var2'FPE=`var2'*FPE
					}
					predict p_`num'_`var'_atFPE0_$r 
					replace `var'=`var'-$h*`num'
					replace FPE=keep_FPE
					foreach vardum of varlist djgovt djpriv{
							replace `vardum'_`var'=`vardum'*`var'
					}
					foreach var2 of varlist $IndRegPre {
							replace `var2'FPE=`var2'*FPE
					}
				}
				gen dpd`var'_atFPE0_$r =(p_1_`var'_atFPE0_$r-p_0_`var'_atFPE0_$r )/$h
				su 	dpd`var'_atFPE0_$r  if j==1
				su 	dpd`var'_atFPE0_$r  if j==2
			}

		********************************
		*** difference in difference ***
		********************************

			foreach var of varlist $Zi {
				replace `var'=`var'+$h
				replace FPE=1
				foreach vardum of varlist djgovt djpriv{
						replace `vardum'_`var'=`vardum'*`var'
				}
				foreach var2 of varlist $IndRegPre {
						replace `var2'FPE=`var2'*FPE
				}
				predict p_11_`var'FPE_$r 
				gen 	dpd`var'FPE_$r=(p_11_`var'FPE_$r-p_1_`var'_atFPE0_$r)/$h- (p_1_FPE_$r - p_0_FPE_$r)/$h
				replace `var'=`var'-$h
				replace FPE=keep_FPE
				foreach vardum of varlist djgovt djpriv{
						replace `vardum'_`var'=`vardum'*`var'
				}
				foreach var2 of varlist $IndRegPre {
						replace `var2'FPE=`var2'*FPE
				}
			}

			inputcoeffs
			program drop deltamethod
}

******************************
*** now calculate g matrix ***
******************************

*** individual regressors
	global IndRegMFX  = "dpdlogfood_atFPE0 dpdlogfoodFPE dpdhhheduc_atFPE0 dpdhhheducFPE"
	local k=0
	foreach num2 of numlist 1/2{
		foreach var of varlist $IndRegMFX {
			local k=`k'+1
			foreach num of numlist 1/`e(df_m)'{
				qui su `var'_0 if j==`num2'
				mat g[`k',`num']=-`r(mean)'
				su 	`var'_`num' if j==`num2'
				mat g[`k',`num']=g[`k',`num']+`r(mean)'
				mat g[`k',`num']=g[`k',`num']/$hh
			}
		}
	}

*** FPE
	local k=10
	foreach num2 of numlist 1/2{
		foreach var of varlist dpdFPE{
			local k=`k'+1
			foreach num of numlist 1/`e(df_m)'{
				qui su `var'_0 if j==`num2'
				mat g[`k',`num']=-`r(mean)'
				su `var'_`num' if j==`num2'
				mat g[`k',`num']=g[`k',`num']+`r(mean)'
				mat g[`k',`num']=g[`k',`num']/0.0001
			}
		}
	}


*** now create the correct Covariance matrix
	local num1=0
	foreach var1 of varlist $ZiXj djgovt djpriv djgovtFPE djprivFPE{
		local num1=`num1'+1
		gen prob`num1'=pinitial*`var1'
	}
	foreach var of varlist prob* {
		bysort iid: egen m`var'=sum(`var')
	}
	local num=0
	foreach var of varlist $ZiXj djgovt djpriv djgovtFPE djprivFPE {
		local num=`num'+1
		gen dev`num'=`var'-mprob`num'
	}
	mat D=I(`e(df_m)')
	foreach num1 of numlist 1/`e(df_m)' {
		foreach num2 of numlist 1/`e(df_m)' {
			matrix vecaccum DD = prob`num1' dev`num2', noconstant
			mat D[`num1',`num2']=DD
		}
	}
	mat COV=inv(D)
	mat COV=g*COV*g'
	mat STD=vecdiag(COV)
	foreach num of numlist 1/`e(df_m)'{
		scalar bla`num'=STD[1,`num']^.5
		matrix STD[1,`num']=bla`num'
	}
	mat STD=STD'


*** Just cosmetically arranging the results...
***	Means are parameter estimates:
	capture mat drop betas errors
	global colnames = ""
	foreach num of numlist 1/2 {
		foreach var of varlist $IndRegMFX{
			su `var' if j==`num'
			mat betas = (nullmat(betas),r(mean))
			global colnames = "$colnames `num':`var'"
		}
	}
	mat colnames betas = $colnames
***	Standard errors:
	mat list STD
	mat errors = STD[1..8,1]'
	mat betas = (betas \ errors)
	mat list betas

exit

